==> blanket_0.7.0.orig.tar.gz: blanket-0.7.0/TRANSLATORS.md <==
# Translators

You can contribute translations joining us in [Transifex](https://www.transifex.com/rafaelmardojai/blanket/) or sending pull requests to GitHub.


| Code  | Language             | Maintainers (GitHub usernames) |
|:-----:|:--------------------:|:------------------------------ |
| ca    | Catalan              | @fitojb @juxuanu               |
| cs    | Czech                | @pervoj                        |
| de    | German               | @eladyn                        |
| eo    | Esperanto            | @Porrumentzio                  |
| es    | Spanish              | @rafaelmardojai                |
| eu    | Basque               | @Porrumentzio                  |
| fa    | Persian              | @mskf1383                      |
| fi    | Finnish              | @heidiwenger                   |
| fr    | French               | @maoschanz @julroy67           |
| ga    | Irish                | @Moilleadoir                   |
| gl    | Galician             | @frandieguez                   |
| hr    | Croatian             | @milotype                      |
| hu    | Hungarian            | @osiixy                        |
| id    | Indonesian           | @cho2                          |
| it    | Italian              | @albanobattistella             |
| ja    | Japanese             |                                |
| ko    | Korean               | @OctopusET                     |
| ne    | Nepali               | @IBA4                          |
| nl    | Dutch                | @Vistaus                       |
| oc    | Occitan              | @Mejans                        |
| pt    | Portuguese           | @JulianoSCbah @hugok79         |
| pt_BR | Brazilian Portuguese | @pedrofleck                    |
| ru_RU | Russian              | @LeftyDeMilo                   |
| sk    | Slovak               | @MartinIIOT                    |
| sr    | Serbian              | @kostich                       |
| sv    | Swedish              | @eson57                        |
| ta    | Tamil                | @123survesh                    |
| tr    | Turkish              | @caglarturali                  |
| uk    | Ukrainian            | @IhorHordiichuk                |
| zh_CN | Simplified Chinese   | @apocelipes                    |
| gr    | Greek                | @Its-Juice

==> blanket_0.8.0.orig.tar.gz: blanket-0.8.0/TRANSLATORS.md <==
# Translators

You can contribute translations by joining us on [Weblate](https://hosted.weblate.org/projects/blanket/) or sending pull requests to GitHub.


| Code  | Language             | Maintainers (GitHub usernames) |
|:-----:|:--------------------:|:------------------------------ |
| ca    | Catalan              | @fitojb @juxuanu               |
| cs    | Czech                | @pervoj                        |
| de    | German               | @eladyn                        |
| en_GB | English (UK)         | @andibing                      |
| eo    | Esperanto            | @Porrumentzio                  |
| es    | Spanish              | @rafaelmardojai                |
| eu    | Basque               | @Porrumentzio                  |
| fa    | Persian              | @mskf1383                      |
| fi    | Finnish              | @heidiwenger                   |
| fr    | French               | @maoschanz @julroy67           |
| ga    | Irish                | @Moilleadoir                   |
| gl    | Galician             | @frandieguez                   |
| gr    | Greek                | @Its-Juice                     |
| hr    | Croatian             | @milotype                      |
| hu    | Hungarian            | @osiixy                        |
| id    | Indonesian           | @cho2                          |
| it    | Italian              | @albanobattistella             |
| ja    | Japanese             |                                |
| ko    | Korean               | @OctopusET                     |
| ne    | Nepali               | @IBA4                          |
| nl    | Dutch                | @Vistaus                       |
| oc    | Occitan              | @Mejans                        |
| pt    | Portuguese           | @JulianoSCbah @hugok79         |
| pt_BR | Brazilian Portuguese | @pedrofleck                    |
| ru_RU | Russian              | @LeftyDeMilo                   |
| sk    | Slovak               | @MartinIIOT                    |
| sr    | Serbian              | @kostich                       |
| sv    | Swedish              | @eson57                        |
| ta    | Tamil                | @123survesh                    |
| tr    | Turkish              | @caglarturali                  |
| uk    | Ukrainian            | @IhorHordiichuk                |
| zh_CN | Simplified Chinese   | @apocelipes                    |
